<form enctype="multipart/form-data" method="post" target="{{ target|default:"_self" }}">
    {% csrf_token %}

    {% if fieldsets %}
        {% for fieldset in fieldsets %}
            {% include 'kmuhelper/_includes/form_fieldset.html' %}
        {% endfor %}
    {% elif form.fieldsets %}
        {% for fieldset in form.fieldsets %}
            {% include 'kmuhelper/_includes/form_fieldset.html' %}
        {% endfor %}
    {% else %}
        {% include 'kmuhelper/_includes/form_fieldset.html' with fieldset=form %}
    {% endif %}

    {{ form.non_field_errors }}
    <input type="submit" value="{{ submit_text|default:"Sichern" }}"/>
</form>
