# Generated by Django 4.1.6 on 2023-02-28 15:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0102_paymentreceiver_improvements"),
    ]

    operations = [
        migrations.AddField(
            model_name="paymentreceiver",
            name="invoice_display_mode",
            field=models.CharField(
                choices=[
                    ("business_orders", "Geschäftlich (Bestellungen)"),
                    ("business_services", "Geschäftlich (Dienstleistungen)"),
                    ("club", "Verein"),
                    ("private", "Privat"),
                ],
                default="business_orders",
                help_text="Je nach Modus werden andere Daten auf der Rechnung angezeigt.",
                max_length=25,
                verbose_name="Anzeigemodus für Rechnungen",
            ),
        ),
    ]
