# Generated by Django 4.1.6 on 2023-03-11 16:57

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0104_order_payment_purpose"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="setting",
            options={
                "default_permissions": ("change",),
                "verbose_name": "Einstellung",
                "verbose_name_plural": "Einstellungen",
            },
        ),
        migrations.AlterModelOptions(
            name="settinghidden",
            options={
                "default_permissions": (),
                "verbose_name": "Versteckte Einstellung",
                "verbose_name_plural": "Versteckte Einstellungen",
            },
        ),
    ]
