# Generated by Django 4.2.7 on 2023-11-22 21:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0105_alter_setting_options_alter_settinghidden_options"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="app_arrival",
            options={
                "default_permissions": [],
                "verbose_name": "Lieferung",
                "verbose_name_plural": "Lieferungen",
            },
        ),
        migrations.AlterModelOptions(
            name="app_incomingpayments",
            options={
                "default_permissions": [],
                "verbose_name": "Bestellung",
                "verbose_name_plural": "Bestellungen",
            },
        ),
        migrations.AlterModelOptions(
            name="app_shipping",
            options={
                "default_permissions": [],
                "verbose_name": "Bestellung",
                "verbose_name_plural": "Bestellungen",
            },
        ),
        migrations.AlterModelOptions(
            name="app_stock",
            options={
                "default_permissions": [],
                "verbose_name": "Produkt",
                "verbose_name_plural": "Produkte",
            },
        ),
        migrations.AlterModelOptions(
            name="app_todo",
            options={
                "default_permissions": [],
                "verbose_name": "Notiz",
                "verbose_name_plural": "Notizen",
            },
        ),
    ]
