{% extends "admin/kmuhelper/app_index.html" %}

{% load kmuhelper_tags %}

{% block title %}KMUHelper E-Mails{% endblock %}

{% block content_title %}
    <h1>Willkommen bei KMUHelper E-Mails!</h1>
{% endblock %}

{% block branding %}
    {% kmuhelper_branding module_name='emails' %}
{% endblock %}

{% block pageinfo %}
    <p id="pageinfo">
        Mit dem KMUHelper E-Mail-Modul kannst du ganz einfach E-Mails erstellen und versenden.
        Die Hauptfunktionen befinden sich im
        <a href="{% url 'admin:app_list' app_label='kmuhelper' %}">
            <abbr title="Admin"><i class="fa-solid fa-key"></i></abbr> Adminbereich
        </a>.
        <a href="{% docs_url 'emails' %}" target="_blank">
            <abbr title="Dokumentation"><i class="fa-solid fa-book"></i></abbr> Handbuch
        </a>
    </p>
{% endblock %}
