:root {
    --kmuhelper-darkest: #880044;
    --kmuhelper-dark: #AA1155;
    --kmuhelper-default: #DD1155;
    --kmuhelper-light: #F6C400;
    --kmuhelper-lightest: #FFEE88;

    /* Default:
    --default-darkest: #036;
    --default-dark: #417690;
    --default-default: #79aec8;
    --default-light: #ffc;
    --default-lightest: #f5dd5d; */
}
