/* Page chooser grid */

.pagechooser {
    --pagechooser-elem-gap: 0.7rem;
    --pagechooser-elem-gap-small: 0.5rem;

    display: flex;
    flex-direction: column;
    gap: var(--pagechooser-elem-gap);
}

.pagechooser .pagechooser-split {
    display: grid;
    gap: var(--pagechooser-elem-gap);
    grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
}

.pagechooser.smallboxes .pagechooser-split {
    gap: var(--pagechooser-elem-gap-small);
    grid-template-columns: repeat(auto-fit, minmax(225px, 1fr));
}

.pagechooser .pagechooser-elem {
    padding: 3rem;
    border-radius: 5px;
    display: block;
    color: white;
    background-color: var(--kmuhelper-dark);
    transition-duration: 0.5s;
    text-decoration: none !important;
}

.pagechooser.smallboxes .pagechooser-elem {
    padding: 1.4rem;
}

.pagechooser .pagechooser-elem:hover {
    background-color: var(--kmuhelper-darkest);
}

.pagechooser .pagechooser-elem-inside {
    display: flex;
    align-items: center;
    text-align: center;
    flex-direction: column;
    gap: 2rem;
}

.pagechooser.smallboxes .pagechooser-elem-inside {
    gap: 1.5rem;
}

.pagechooser .pagechooser-icon {
    flex-shrink: 0;
}

.pagechooser .pagechooser-text-container {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    gap: .5rem;
}

.pagechooser .pagechooser-text-container h2,
.pagechooser .pagechooser-text-container p {
    margin: 0;
}

.initialwidth {
    width: initial !important;
}

@media screen and (max-width: 767px) {
    .pagechooser .pagechooser-split {
        grid-template-columns: 1fr;
    }

    .pagechooser .pagechooser-elem {
        padding: 1.25rem 1.5rem;
    }

    .pagechooser .pagechooser-elem-inside {
        flex-direction: row;
        gap: 1.5rem;
        text-align: left;
    }
}
