{% load static %}

<meta name="theme-color" content="#880044">
<link rel="shortcut icon" type="image/x-icon" href="{% static 'kmuhelper/favicon.ico' %}">
<link rel="apple-touch-icon" href="{% static 'kmuhelper/favicon.ico' %}">
<link rel="manifest" href="{% url 'kmuhelper:manifest' %}">
