# Generated by Django 4.1.6 on 2023-02-28 22:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0103_paymentreceiver_invoice_display_mode"),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="payment_purpose",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="Zahlungszweck",
                help_text="Wird in QR-Rechnung verwendet.",
            ),
        ),
    ]
