# Generated by Django 5.0.4 on 2024-04-06 20:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0111_alter_order_tracking_number"),
    ]

    operations = [
        migrations.AddField(
            model_name="product",
            name="parent",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="children",
                to="kmuhelper.product",
                verbose_name="Übergeordnetes Produkt",
            ),
        ),
    ]
