{% extends 'admin/kmuhelper/base_site.html' %}

{% load static %}

{% block title %}PDF generieren | KMUHelper{% endblock %}

{% block breadcrumbs %}
    <div id="breadcrumbs" class="breadcrumbs">
        <a href="{% url 'admin:app_list' app_label='kmuhelper' %}">KMUHelper Admin</a>
        &rsaquo; <a href="{% url 'admin:kmuhelper_order_changelist' %}">Bestellungen</a>
        &rsaquo; <a href="{% url 'admin:kmuhelper_order_change' object_id=original.pk %}">{{ original }}</a>
        &rsaquo; PDF generieren
    </div>
{% endblock %}

{% block extrahead %}
    <link rel="stylesheet" href="{% static 'admin/css/forms.css' %}">
{% endblock %}

{% block content_title %}
    <h1>PDF generieren: {{ original }}</h1>
{% endblock %}

{% block content %}
    {% include 'kmuhelper/_includes/form.html' with target="_blank" submit_text="PDF generieren" %}
{% endblock %}