{% extends "admin/kmuhelper/base_site.html" %}

{% load static kmuhelper_tags %}

{% block title %}KMUHelper Statistiken{% endblock %}

{% block extrahead %}
    {% block chartjs %}
        <!-- ChartJS https://www.chartjs.org/docs/latest/getting-started/ -->

        <script src="https://cdn.jsdelivr.net/npm/chart.js@4.4.8/dist/chart.umd.min.js"
                integrity="sha512-IMvjDnJzMKoQZLPYQHxR4g8nm0sSd9bR7Kl5ayxnPHV8ChqVpHCdBYXGib3ZftuDlfaceqn7t47fObseBCEEJw=="
                crossorigin="anonymous"></script>
        <script src="https://cdn.jsdelivr.net/npm/chartjs-adapter-date-fns@3.0.0/dist/chartjs-adapter-date-fns.bundle.min.js"
                integrity="sha512-VPUN3sK5Jce8lVuVWfTZolO+BDodUHFq1QsNHmszMbKpYrQzjCxvC0FDG7igWCYBcsFDpqhcVq4sQ851OqhAPg=="
                crossorigin="anonymous"></script>
    {% endblock %}

    {{ block.super }}
{% endblock %}

{% block branding %}
    {% kmuhelper_branding module_name='stats' %}
{% endblock %}

{% block breadcrumbs %}{% endblock %}
