{% extends 'kmuhelper/emails/base.html' %}

{% block extrahead %}
    <style>
        table tr:nth-child(even) {
            background-color: #f2f2f2;
        }
    </style>
{% endblock %}

{% block title %}KMUHelper | E-Mails{% endblock %}

{% block subtitle %}Warnung zum Lagerbestand{% endblock %}

{% block maincontent %}

    <p>
        Seit einer kürzlich importierten Bestellung
        {% if orderinfo %}
            ({{ orderinfo }})
        {% endif %}
        herrscht Knappheit beim Lagerbestand folgender Produkte:</p>
    <br>

    <table style="border-collapse: collapse; width: 100%;">
        <tbody>
        <tr>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;"
                colspan=2>Produkt
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;"
                colspan=4>Lagerbestand
            </th>
        </tr>
        <tr>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                ID
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                Name
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                Aktuell
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                Soll
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                Ausgehend
            </th>
            <th style="border: 1px solid #ddd; padding: 12px 8px; text-align: left; background-color: #AA1155; color: white;">
                Eingehend
            </th>
        </tr>
        {% for w in warnings %}
            <tr>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.product.id }}</td>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.product.name }}</td>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.stock.current }}</td>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.stock.min }}</td>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.stock.going }}</td>
                <td style="border: 1px solid #ddd; padding: 8px;">{{ w.stock.coming }}</td>
            </tr>
        {% endfor %}
        </tbody>
    </table>

    <br>

    <p>Als "ausgehend" werden alle Produkte gezählt, welche sich in Bestellungen befinden, aber noch nicht als versendet
        markiert wurden. Als "eingehend" werden alle Produkte gezählt, welche sich in Lieferungen befinden, aber noch
        nicht als eingelagert markiert wurden.</p>

    <p>PS: Sie erhalten diese E-Mail, weil Sie in den Einstellungen diese E-Mail Adresse für Warnungen zum Lagerbestand
        eingetragen haben.</p>

{% endblock %}

{% block postcontent %}
{% endblock %}