# Generated by Django 5.0.4 on 2024-04-17 20:28

import django.core.validators
import kmuhelper.modules.main.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("admin", "0003_logentry_add_action_flag_choices"),
        ("kmuhelper", "0113_customer_woocommerce_deleted_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="AdminLogEntry",
            fields=[],
            options={
                "verbose_name": "Admin-Logeintrag",
                "verbose_name_plural": "Admin-Logeinträge",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("admin.logentry",),
        ),
        migrations.AlterField(
            model_name="order",
            name="payment_conditions",
            field=models.CharField(
                blank=True,
                default=kmuhelper.modules.main.models.default_payment_conditions,
                help_text='Skonto und Zahlungsfrist -> <a target="_blank" href="https://rafaelurben.github.io/django-kmuhelper/manual/faq#wie-funktionieren-zahlungskonditionen">FAQ</a>',
                max_length=25,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]+(\\.[0-9]+)?:[0-9]+;)*0:[0-9]+$",
                        "Bitte benutze folgendes Format: 'p:d;p:d' - p = Skonto in %; d = Tage",
                    )
                ],
                verbose_name="Zahlungskonditionen",
            ),
        ),
    ]
