{% extends 'admin/kmuhelper/change_list.html' %}

{% load static %}

{% block pageinfo %}
    <p id="pageinfo">
        <b>Verwandte Seiten:</b>
        <a href="{% url 'admin:kmuhelper_note_changelist' %}">
            <abbr title="Admin"><i class="fa-solid fa-key"></i></abbr> Alle Notizen
        </a>
    </p>
{% endblock %}

{% block extrahead %}
    {{ block.super }}

    {% comment %} Load the changelist save on top script {% endcomment %}
    <script src="{% static 'admin/kmuhelper/js/changelist_saveontop.js' %}"></script>
{% endblock %}
