<table>
    <thead>
    <tr>
        <th>Bestellung
            <a target="_blank"
               href="{% url 'admin:kmuhelper_order_change' object_id=order.pk %}" rel="noopener noreferrer">
                #{{ order.pk }}
            </a>
        </th>
        <th>
            <abbr title="Hier klicken, um die Bestellung als bezahlt zu markieren">
                <a class="button markpaid{% if order.is_paid %} success{% endif %}"
                   data-url="{% url 'kmuhelper:api-orders-set-paid' order.pk %}" rel="noopener noreferrer">
                    Bezahlt
                </a>
            </abbr>
        </th>
    </tr>
    </thead>
    <tbody>
    <tr>
        <td>Zahlungskonditionen:</td>
        <td>{{ order.display_payment_conditions }}</td>
    </tr>
    <tr>
        <td>Rechnungsdatum:</td>
        <td>{{ order.invoice_date }}</td>
    </tr>
    </tbody>
</table>