{% extends 'admin/kmuhelper/base_site.html' %}

{% load static %}

{% block title %}XML-Upload | KMUHelper Zahlungsimport{% endblock %}

{% block breadcrumbs %}
    <div id="breadcrumbs" class="breadcrumbs">
        <a href="{% url 'admin:app_list' app_label='kmuhelper' %}">KMUHelper Admin</a>
        &rsaquo; <a href="{% url 'admin:kmuhelper_paymentimport_changelist' %}">Zahlungsimporte</a>
        &rsaquo; XML-Upload
    </div>
{% endblock %}

{% block extrahead %}
    <link rel="stylesheet" href="{% static 'admin/css/forms.css' %}">
{% endblock %}

{% block content_title %}
    <h1>Zahlungsimport - XML-Upload</h1>
{% endblock %}

{% block content %}
    <p>
        Hier können XML-Dateien nach ISO20022 Standard hochgeladen werden.
        <br>
        Zurzeit werden nur camt.053.001.04 mit Detailinformationen (053d) unterstützt.
    </p>

    <br>

    {% include 'kmuhelper/_includes/form.html' with submit_text="Hochladen" %}
{% endblock %}