{% extends "admin/base_site.html" %}

{% load static kmuhelper_tags %}

{% block title %}{{ title }} | KMUHelper{% endblock %}

{% block branding %}
    {% kmuhelper_branding %}
{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'admin/kmuhelper/css/style.css' %}">
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v6.5.2/css/all.css"
          integrity="sha384-PPIZEGYM1v8zp5Py7UjFb79S58UeqCL9pYVnVPURKEqvioPROaVAJKKLzvH2rDnI" crossorigin="anonymous">
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    {% include "kmuhelper/_includes/pwa_head.html" %}
{% endblock %}
