{% extends "kmuhelper/stats/base.html" %}

{% block chartjs %}
{% endblock %}

{% block content %}

    <h1>Willkommen bei KMUHelper Statistiken!</h1>

    <p>
        Diese Funktion ist mehr oder weniger in der ewigen Probephase, da kein besonderes Interesse daran besteht.
        <br>
        Möglicherweise werden in Zukunft weitere Statistiken und Funktionen eingebaut.
    </p>

    <br>

    <h3>Statistiken</h3>

    <ul>
        <li><a class="link" href="{% url 'kmuhelper:stats-products-price' %}">Produkt &amp; Preis</a></li>
        <li><a class="link" href="{% url 'kmuhelper:stats-best-products' %}">Beste Produkte</a></li>
    </ul>

    <br>

    <h3>Parameter</h3>
    <p>Statistiken können mit folgenden Parametern eingeschränkt werden:</p>

    <br>

    <table>
        <thead>
        <tr>
            <th>Parameter</th>
            <th>Format</th>
            <th>Funktion</th>
            <th>Beispiel</th>
        </tr>
        </thead>
        <tbody>
        <tr>
            <td><kbd>from</kbd></td>
            <td>YYYY-mm-dd</td>
            <td>Nur Einträge ab diesem Datum anzeigen</td>
            <td><kbd>?from=2020-06-20</kbd></td>
        </tr>
        <tr>
            <td><kbd>to</kbd></td>
            <td>YYYY-mm-dd</td>
            <td>Nur Einträge bis zu diesem Datum anzeigen</td>
            <td><kbd>?to=2020-10-24</kbd></td>
        </tr>
        <tr>
            <td><kbd>max</kbd>*</td>
            <td>n</td>
            <td>Anzahl Einträge beschränken/erhöhen</td>
            <td><kbd>?max=35</kbd></td>
        </tr>
        </tbody>
    </table>

    <br>

    <p>Beispiel: <kbd>?from=2020-06-20&amp;to=2020-10-24&amp;max=35</kbd></p>

    <p>* = nicht bei allen Statistiken vorhanden</p>

{% endblock %}
