# Generated by Django 5.0 on 2024-02-01 16:37

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0110_orderitem_made_product_optional"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="tracking_number",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Trackingnummer ohne Leerzeichen. (optional)",
                max_length=35,
                validators=[
                    django.core.validators.RegexValidator(
                        "^[A-Z0-9\\.]{8,}$",
                        "Erlaubte Zeichen: Grossbuchstaben, Zahlen und Punkte. Länge: 8-35 Zeichen",
                    )
                ],
                verbose_name="Trackingnummer",
            ),
        ),
    ]
