# Generated by Django 5.0.4 on 2024-04-09 14:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0112_product_parent"),
    ]

    operations = [
        migrations.AddField(
            model_name="customer",
            name="woocommerce_deleted",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Deleted in WooCommerce?"
            ),
        ),
        migrations.AddField(
            model_name="order",
            name="woocommerce_deleted",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Deleted in WooCommerce?"
            ),
        ),
        migrations.AddField(
            model_name="product",
            name="woocommerce_deleted",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Deleted in WooCommerce?"
            ),
        ),
        migrations.AddField(
            model_name="productcategory",
            name="woocommerce_deleted",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Deleted in WooCommerce?"
            ),
        ),
    ]
