{% extends 'admin/kmuhelper/change_list.html' %}

{% load kmuhelper_tags %}

{% block pageinfo %}
    <p id="pageinfo">
        <b>Verwandte Seiten:</b>
        <a href="{% url 'admin:kmuhelper_app_incomingpayments_changelist' %}">
            <abbr title="App"><i class="fa-solid fa-desktop"></i></abbr> Zahlungseingang
        </a>
        <a href="{% docs_url 'integrations/paymentimport' %}" target="_blank">
            <abbr title="Dokumentation"><i class="fa-solid fa-book"></i></abbr> Zahlungsimport
        </a>
    </p>
{% endblock %}

{% block object-tools-items %}
    {% if perms.kmuhelper.add_paymentimport %}
        <li><a href="{% url 'admin:kmuhelper_paymentimport_upload' %}">XML Datei hochladen</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}
