{% extends 'admin/kmuhelper/change_list.html' %}

{% block pageinfo %}
    <p id="pageinfo">
        <b>Verwandte Seiten:</b>
        <a href="{% url 'admin:kmuhelper_product_changelist' %}">
            <abbr title="Admin"><i class="fa-solid fa-key"></i></abbr> Produkte
        </a>
    </p>
{% endblock %}

{% block object-tools-items %}
    {% load kmuhelper_tags %}
    {% kmuhelper_woocommerce_connected as woocommerce_is_connected %}
    {% if woocommerce_is_connected and perms.kmuhelper.add_productcategory %}
        <li>
            <a onclick="woocommerce_loading_swal();" href="{% url 'kmuhelper:wc-import-categories' %}" class="addlink">Kategorien von
                WooCommerce importieren</a>
        </li>
    {% endif %}
    {{ block.super }}
{% endblock %}