{% extends 'admin/kmuhelper/change_form.html' %}

{% block object-tools-items %}
    {% if change %}
        {% if original.woocommerceid %}
            <li><a href="{% url 'kmuhelper:wc-update-category' object_id %}">Von WooCommerce importieren und
                ersetzen</a></li>
        {% endif %}
    {% endif %}
    {{ block.super }}
{% endblock %}
