# Generated by Django 5.0.7 on 2024-07-17 22:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("kmuhelper", "0115_migrate_payment_receiver_address_format"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="customer",
            index=models.Index(
                fields=["woocommerceid"], name="kmuhelper_c_woocomm_b647fd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="order",
            index=models.Index(
                fields=["woocommerceid"], name="kmuhelper_o_woocomm_8db6e3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="product",
            index=models.Index(
                fields=["woocommerceid"], name="kmuhelper_p_woocomm_34f8a4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="productcategory",
            index=models.Index(
                fields=["woocommerceid"], name="kmuhelper_p_woocomm_a29e62_idx"
            ),
        ),
    ]
