{% extends 'kmuhelper/emails/base.html' %}

{% block subtitle %}Registrierung erfolgreich{% endblock %}

{% block maincontent %}

    {% if not text %}
        <p>Sehr geehrter Kunde</p>
        <p>Sie wurden erfolgreich in unserer Datenbank mit folgenden Daten registriert:</p>
    {% else %}
        {{ text|urlize|linebreaks }}
    {% endif %}

    <ul>
        <li>Kundennummer: {{ customer.id }}</li>
        <li>Vorname: {{ customer.first_name }}</li>
        <li>Nachname: {{ customer.last_name }}</li>
        <li>Firma: {{ customer.company }}</li>
        <li>E-Mail: {{ customer.email }}</li>
    </ul>

    <p>
        Zusätzlich dazu werden von uns auch Rechnungsadresse, Lieferadresse sowie vergangene Bestellungen gespeichert.
    </p>
    <p>
        Bei Fragen oder Problemen können Sie uns jederzeit kontaktieren.
    </p>

{% endblock %}