{% extends "admin/submit_line.html" %}

{% block submit-row %}

    {% if change and perms.kmuhelper.add_order %}
        <a class="button" href="{% url 'admin:kmuhelper_order_duplicate' object_id %}">Duplizieren</a>
    {% endif %}

    {{ block.super }}

{% endblock %}