{% extends 'admin/kmuhelper/base_site.html' %}

{% load static kmuhelper_tags %}

{% block title %}Einstellungen | KMUHelper{% endblock %}

{% block breadcrumbs %}
{% endblock %}

{% block branding %}
    {% kmuhelper_branding module_name='settings' %}
{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'admin/css/forms.css' %}">
    <link rel="stylesheet" href="{% static 'admin/kmuhelper/css/style.css' %}">
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    <script src="{% static 'admin/kmuhelper/js/beforeunload.js' %}" type="text/javascript"></script>
    <script src="{% static 'admin/js/vendor/jquery/jquery.js' %}" type="text/javascript"></script>
{% endblock %}

{% block content_title %}
    <h1>Einstellungen</h1>
{% endblock %}

{% block content %}
    {% include 'kmuhelper/_includes/form.html' with submit_text="Einstellungen speichern" %}

    <hr style="margin-top: 2em; margin-bottom: 2em;">
    <h2>Weitere Optionen</h2>

    <div style="margin-top: 2em;">
        <a href="{% url 'kmuhelper:wc-settings' %}">
            <button class="button">Zu den WooCommerce-Einstellungen</button>
        </a>
    </div>

    <div style="margin-top: 2em;">
        <i>
            <a class="link" href="{% url 'kmuhelper:build-info' %}">Build-Info</a> anzeigen
        </i> |
        <i>
            Zur <a class="link" href="{% url 'admin:kmuhelper_setting_changelist' %}">alten Ansicht</a> wechseln
        </i>
    </div>
{% endblock %}
