{% extends 'admin/kmuhelper/change_list.html' %}

{% block pageinfo %}
    <p id="pageinfo">
        <b>Verwandte Seiten:</b>
        <a href="{% url 'admin:kmuhelper_supplier_changelist' %}">
            <abbr title="Admin"><i class="fa-solid fa-key"></i></abbr> Lieferanten
        </a>
        <a href="{% url 'admin:kmuhelper_app_arrival_changelist' %}">
            <abbr title="App"><i class="fa-solid fa-desktop"></i></abbr> Wareneingang
        </a>
    </p>
{% endblock %}