{% extends "admin/object_history.html" %}
{% load i18n admin_urls static kmuhelper_tags %}

{% block title %}{{ title }} | KMUHelper{% endblock %}

{% block breadcrumbs %}
    {% get_admin_module as module %}
    {% get_admin_model as model %}

    <div class="breadcrumbs">
        <a href="{% url module.viewname %}">KMUHelper {{ module.title }}</a>
        &rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">
        {{ model.ADMIN_TITLE | default:opts.verbose_name_plural  }}</a>
        &rsaquo; <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">
        {{ object|truncatewords:"18" }}</a>
        &rsaquo; {% translate 'History' %}
    </div>
{% endblock %}

{% block branding %}
    {% kmuhelper_branding %}
{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'admin/kmuhelper/css/style.css' %}">
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v6.5.2/css/all.css"
          integrity="sha384-PPIZEGYM1v8zp5Py7UjFb79S58UeqCL9pYVnVPURKEqvioPROaVAJKKLzvH2rDnI" crossorigin="anonymous">
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    {% include "kmuhelper/_includes/pwa_head.html" %}
{% endblock %}
