{% extends 'kmuhelper/emails/base.html' %}

{% block maincontent %}

    {% if not text %}
        <p>Sehr geehrter Kunde</p>
        <p>
            Im Anhang finden Sie Ihre Rechnung zur Bestellung Nr.
            {{ id }}{% if woocommercedata %} (Online #{{ woocommerceid }}){% endif %}
        </p>
    {% else %}
        {{ text|urlize|linebreaks }}
    {% endif %}

    {% if trackingdata %}
        <p>Sie können die Bestellung über <a href="{{ tracking_link }}">diesen Link</a> verfolgen, sobald sie von der
            Post verarbeitet wurde.</p>
    {% endif %}

{% endblock %}