{% extends 'admin/kmuhelper/change_list.html' %}

{% load static kmuhelper_tags %}

{% block breadcrumbs %}
{% endblock %}

{% block content %}
    {{ block.super }}

    <div style="margin-top: 2em;">
        <i>
            <a class="link" href="{% url 'kmuhelper:build-info' %}">Build-Info</a> anzeigen
        </i> |
        <i>
            Zur <a class="link" href="{% url 'kmuhelper:settings' %}">neuen Ansicht</a> wechseln
        </i>
    </div>
{% endblock %}
